@@ -182,6 +182,9 @@ def accepts(
                     api=api,
                     operation="load",
                 )
+                if schema.many is True:
+                    body = [body]
+
                 params = {
                     "expect": [body, _parser],
                 }
@@ -303,7 +306,7 @@ def responds(
             elif _parser:
                 api.add_model(model_name, model_from_parser)
                 inner = _document_like_marshal_with(
-                    model_from_parser, status_code=status_code
+                    model_from_parser, status_code=status_code, description=description
                 )(inner)
 
         return inner
